[llvm-commits] CVS: llvm/lib/CodeGen/IntrinsicLowering.cpp

Chris Lattner sabre at nondot.org
Wed Nov 15 10:00:28 PST 2006



Changes in directory llvm/lib/CodeGen:

IntrinsicLowering.cpp updated: 1.45 -> 1.46
---
Log message:

Simplify IntrinsicLowering and clarify that it is only for use by the
CBE and interpreter.


---
Diffs of the changes:  (+3 -3)

 IntrinsicLowering.cpp |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)


Index: llvm/lib/CodeGen/IntrinsicLowering.cpp
diff -u llvm/lib/CodeGen/IntrinsicLowering.cpp:1.45 llvm/lib/CodeGen/IntrinsicLowering.cpp:1.46
--- llvm/lib/CodeGen/IntrinsicLowering.cpp:1.45	Wed Nov  8 00:47:33 2006
+++ llvm/lib/CodeGen/IntrinsicLowering.cpp	Wed Nov 15 12:00:10 2006
@@ -7,7 +7,7 @@
 //
 //===----------------------------------------------------------------------===//
 //
 // This file implements the default intrinsic lowering implementation.
 //
 //===----------------------------------------------------------------------===//
 
@@ -82,7 +82,7 @@
   return NewCI;
 }
 
-void DefaultIntrinsicLowering::AddPrototypes(Module &M) {
+void IntrinsicLowering::AddPrototypes(Module &M) {
   for (Module::iterator I = M.begin(), E = M.end(); I != E; ++I)
     if (I->isExternal() && !I->use_empty())
       switch (I->getIntrinsicID()) {
@@ -263,7 +263,7 @@
 
 
 
-void DefaultIntrinsicLowering::LowerIntrinsicCall(CallInst *CI) {
+void IntrinsicLowering::LowerIntrinsicCall(CallInst *CI) {
   Function *Callee = CI->getCalledFunction();
   assert(Callee && "Cannot lower an indirect call!");
 
@@ -7,7 +7,7 @@
 //===----------------------------------------------------------------------===//
 //
-// This file implements the default intrinsic lowering implementation.
+// This file implements the IntrinsicLowering class.
 //
 //===----------------------------------------------------------------------===//






More information about the llvm-commits mailing list